==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/view/rozdeleniosoby.php <==
<?php
/**
 * stanislav.elbl, 26.11.2014
 *
 * Dialog pro vyber "oblibenych" rozdeleni (denni vysledky, sluzebni cesty)
 */

namespace Ron\RonPortal;

use Ron\StringUtils;

/**
 * @var TypRozdeleni $typrozdeleni
 */

global $appVersion;

?>
<!--suppress HtmlUnknownTarget -->
<script type="text/javascript" src="script/rozdeleniosoby.js?ver=<?= $appVersion ?>"></script>

<div id="rozdeleniosobydialog" class="" title="<?= StringUtils::htmlTextConvert($typrozdeleni ->popis) ?>" style="display: none;">
    <form name="rozdeleniosobyform">

        <div class="dialogcontent">
<!--            <input type="hidden" name="selectedvalue" value="" />-->
<!--            <input type="hidden" name="rozdeleniosobypost" value="1" />-->
            <table class="shiftform">
                <tr>
                    <td><?= \Ron\ronText('Neprirazene_rozdeleni') ?></td>
                    <td></td>
                    <td><?= \Ron\ronText('Prirazene_rozdeleni') ?></td>
                </tr>

                <tr>
                    <td>
                        <div class="shiftformpanel leftpanel">
                            <table class="rontable" id="NeprirazeneRozdeleni" style="width:100%"></table>
                        </div>
                    </td>
                    <td class="shiftformbuttonscell">
                        <div class="shiftformbuttons">
                            <i id="priradRozdeleniOsoby" class="inline-glyph glyph-button fa glyph-move-right" title="<?= \Ron\ronText('Pridat') ?>" ></i><br/>
                            <br/>
                            <i id="zrusRozdeleniOsoby" class="inline-glyph glyph-button fa glyph-move-left" title="<?= \Ron\ronText('Odebrat') ?>"></i><br/>
                        </div>
                    </td>
                    <td>
                        <div class="shiftformpanel rightpanel">
                            <table class="rontable" id="PrirazeneRozdeleni" style="width:100%"></table>
                        </div>
                    </td>
                </tr>

                <tr>
                    <td colspan="3"><?= \Ron\ronText('Vyhledavani') ?>: </td>
                </tr>
                <tr>
                    <td colspan="3">
                        <input type="text" name="filtrrozdeleni" id="filtrrozdeleni" />
                </tr>
                <tr>
                    <td colspan="3">
                        <input type="button" class="button" name="vyhledat" id="vyhledatRozdeleni" disabled="disabled" value="<?= \Ron\ronText('Vyhledat') ?>"/>
                        <span id="InfoPocetRozdeleni"></span>

                        <span class="float-right"><input type="button" class="button" name="OK" id="RozdeleniOK" value="<?= \Ron\ronText('OK') ?>"/></span>
                    </td>
                </tr>
            </table>
        </div>

    </form>
</div>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/view/rozdeleniosoby.php <==
<?php
/**
 * stanislav.elbl, 26.11.2014
 *
 * Dialog pro vyber "oblibenych" rozdeleni (denni vysledky, sluzebni cesty)
 */

namespace Ron\RonPortal;

use Ron\StringUtils;
use RonPortal\Security;

/**
 * @var TypRozdeleni $typrozdeleni
 * @var string $url
 */

global $appVersion;

?>
<!--suppress HtmlUnknownTarget -->
<script type="text/javascript" src="script/rozdeleniosoby.js?ver=<?= $appVersion ?>"></script>

<div id="rozdeleniosobydialog" class="d-none" title="<?= StringUtils::htmlTextConvert($typrozdeleni ->popis) ?>" data-url="<?= $url ?>" data-csrf-key="<?= Security::getCsrfKey() ?>">
    <form name="rozdeleniosobyform">

        <div class="dialogcontent">
<!--            <input type="hidden" name="selectedvalue" value="" />-->
<!--            <input type="hidden" name="rozdeleniosobypost" value="1" />-->
            <table class="shiftform">
                <tr>
                    <td><?= \Ron\ronText('Neprirazene_rozdeleni') ?></td>
                    <td></td>
                    <td><?= \Ron\ronText('Prirazene_rozdeleni') ?></td>
                </tr>

                <tr>
                    <td>
                        <div class="shiftformpanel leftpanel">
                            <table class="rontable w-100" id="NeprirazeneRozdeleni"></table>
                        </div>
                    </td>
                    <td class="shiftformbuttonscell">
                        <div class="shiftformbuttons">
                            <i id="priradRozdeleniOsoby" class="inline-glyph glyph-button fa glyph-move-right" title="<?= \Ron\ronText('Pridat') ?>" ></i><br/>
                            <br/>
                            <i id="zrusRozdeleniOsoby" class="inline-glyph glyph-button fa glyph-move-left" title="<?= \Ron\ronText('Odebrat') ?>"></i><br/>
                        </div>
                    </td>
                    <td>
                        <div class="shiftformpanel rightpanel">
                            <table class="rontable w-100" id="PrirazeneRozdeleni"></table>
                        </div>
                    </td>
                </tr>

                <tr>
                    <td colspan="3"><?= \Ron\ronText('Vyhledavani') ?>: </td>
                </tr>
                <tr>
                    <td colspan="3">
                        <input type="text" name="filtrrozdeleni" id="filtrrozdeleni" />
                </tr>
                <tr>
                    <td colspan="3">
                        <input type="button" class="button" name="vyhledat" id="vyhledatRozdeleni" disabled="disabled" value="<?= \Ron\ronText('Vyhledat') ?>"/>
                        <span id="InfoPocetRozdeleni"></span>

                        <span class="float-right"><input type="button" class="button" name="OK" id="RozdeleniOK" value="<?= \Ron\ronText('OK') ?>"/></span>
                    </td>
                </tr>
            </table>
        </div>

    </form>
</div>
